# Keycloak

In the Shivering-Isles Infrastructure Keycloak is the central identity provider. It allows users to manage their sessions and provides Multi-Factor authentication for all services.

The Keycloak instance is usually referred to as ["SI-Auth"](https://auth.shivering-isles.com). The Shivering-Isles realm contains the user-base. The Keycloak system realm, called "Master,"  administrates the Shivering-Isles realm.

While the Shivering-Isles realm is accessible over the internet, allowing easy access and authentication from everywhere in the world, the "master" realm is only accessible through the local-network administration endpoint. This reduces the risk of a take over, even if an attacker compromises credentials.


## Authentication configuration

To allow Multi-Factor-Authentication (MFA) a copy of the web browser flow was adjusted to account for WebAuthn and TOTP-based MFA.

![Keycloak flow with both TOTP and WebAuthn as MFA options.](images/authentication-config.png)

The official Keycloak documentation describes the basics to [set up WebAuthn as MFA flow](https://www.keycloak.org/docs/latest/server_admin/index.html#_webauthn-authenticator-setup).

While Passwordless authentication is prepared to be rolled out, some experimentation showed that the authentication flow becomes too complex.

For some apps, like [Paperless](./paperless.md), there is also an adjusted authentication flow using [step-up authentication](https://www.keycloak.org/docs/latest/server_admin/index.html#_step-up-flow). This helps to enforce authentication in shorter periods of time, making it easy to keep SSO sessions long, while privileged access has much shorter authentication windows.

![Keycloak flow with step-up authentication using WebAuthn.](images/authentication-stepup.png)

## Google Login

Recently the use of third-party login systems was added in form of [allowing Google Authentication](https://www.keycloak.org/docs/latest/server_admin/index.html#_google) to be used. Most importantly, one can not sign-up using Google Authentication, but link it to an existing Account. This allows the usage of Google Authentication with a SI-Auth account reducing the friction introduced by Authentication. Especially for Friends and Family members that are not pushing for maximum account security and struggle with MFA, this is a safe option given Google good track record of protecting from account take-overs and the device authentication integration with Android.

Using SI-Auth instead of allowing direct authentication through Google on apps directly, ensures that no accounts actually depend on Google and migrations to non-social or different social logins are easily possible.

Links
---

- [Source Code](https://github.com/keycloak/keycloak)
- [Documentation](https://www.keycloak.org/documentation)
- [Helm Chart](https://artifacthub.io/packages/helm/si-gitops/keycloak)
